.. :changelog:

History
-------

0.1.0 (2015-02-03)
++++++++++++++++++

* First release on PyPI.

0.1.1 (2015-02-04)
++++++++++++++++++

* Add AbstractSchedule

0.1.2 (2015-02-04)
++++++++++++++++++

* Renamed package from ``schedule`` to a less general name ``tinyschedule`` to avoid conflicts.

0.1.3 (2015-02-05)
++++++++++++++++++

* Small bugfix: if you subclass AbstractSchedule, you will now get your own class when using ``ScheduleManager.lookup(...)``

0.1.4 (2015-03-10)
++++++++++++++++++

* Bugfix in __getitem__

